entity_validator — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »
- validator »

# entity_validator

class `camelot.admin.validator.entity_validator.` `EntityValidator`(admin, model, initial_validation=False)

  A validator class validates an entity before flushing it to the database and provides the user with feedback if the entity is not ready to flush

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »
- validator »

Comments
blog comments powered by Disqus